@@ -26,7 +26,7 @@
 
 #include <xfconf/xfconf.h>
 #include <libxfce4ui/libxfce4ui.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "notification-plugin.h"
 #include "notification-plugin-log.h"
@@ -74,12 +74,12 @@ notification_plugin_configure (XfcePanelPlugin      *plugin,
   xfce_panel_plugin_block_menu (plugin);
 
   /* create the dialog */
-  dialog = xfce_titled_dialog_new_with_buttons (_("Notification Plugin Settings"),
-                                                GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-                                                GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                "gtk-help", GTK_RESPONSE_HELP,
-                                                "gtk-close", GTK_RESPONSE_OK,
-                                                NULL);
+  dialog = xfce_titled_dialog_new_with_mixed_buttons (_("Notification Plugin Settings"),
+                                                      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
+                                                      GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                      "help-browser", _("_Help"), GTK_RESPONSE_HELP,
+                                                      "window-close-symbolic", _("_Close"), GTK_RESPONSE_OK,
+                                                      NULL);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), ICON_NAME);
   gtk_widget_show (dialog);
